@@ -349,7 +349,7 @@ plotDensitySplitByCustom <- function(data_path,
 #' @import ggeasy
 #' @export
 plotDensityStackedByDuration <- function(data_path,
-                                         graph_title = "Call Distribution Grouped by Duration of Vocalization (s)",
+                                         graph_title = "Call Distribution Grouped by Duration (s)",
                                          graph_subtitle = "Duration groups are rounded to the nearest 0.01 second.",
                                          chosen_group = c()) {
   excel_file <- loadSpecData(data_path)
@@ -399,7 +399,7 @@ plotDensityStackedByDuration <- function(data_path,
 #' @import ggeasy
 #' @export
 plotDensitySplitByDuration <- function(data_path,
-                                       graph_title = "Call Distribution Grouped by Duration of Vocalization",
+                                       graph_title = "Call Distribution Grouped by Duration (s)",
                                        graph_subtitle = "Duration groups are rounded to the nearest 0.01 second.",
                                        chosen_group = c()) {
   excel_file <- loadSpecData(data_path)
@@ -538,7 +538,8 @@ plotPrincipalBoxplot <- function(data_path,
 #' @import ggpubr
 #' @import dplyr
 #' @import ggeasy
-#' @import ggcorrplot
+#' @importFrom ggcorrplot ggcorrplot
+#' @importFrom stats cor
 #' @export
 plotCorrelations <- function(data_path,
                              graph_title = "Correlation Matrix",
@@ -549,8 +550,8 @@ plotCorrelations <- function(data_path,
       `Slope (kHz/s)`, `Sinuosity`, `Mean Power (dB/Hz)`, `Tonality`, `Peak Freq (kHz)`
     )
 
-  corr.mat <- round(cor(excel_file), 1)
-  ggcorrplot(corr.mat,
+  sqkr_correlation_matrix <- round(cor(excel_file), 1)
+  ggcorrplot(sqkr_correlation_matrix,
     hc.order = TRUE, outline.color = "white",
     type = "lower", ggtheme = ggplot2::theme_gray, lab = TRUE
   ) +
